<?PHP

/*

   STELLAR MAGNITUDE OF THE SUN

   THIS PROGRAM COMPUTES THE IDEAL APPARENT MAGNITUDE OF THE
   SUN AT ANY GIVEN DISTANCE IN AUs, LIGHT YEARS AND PARSECS.

   AUTHOR     : Jay Tanner
   LANGUAGE   : PHP 5.4.7

*/

   $ProgramVersion = 'v3.0';

   $cYear = date('Y');

   define ('AU_PER_LY' , '63241.0769574441336802');
   define ('AU_PER_PC' , '206264.8062470963551565');

// ----------------------------
// Set page title and headings.

   $_ACTION_FILE_NAME_    = $_SERVER['SCRIPT_NAME'];

   $_INTERNAL_PAGE_TITLE_ = "Visual Stellar Magnitude of the Sun at Any Given Distance";

   $_PAGE_HEADING_ = "<span style='font-size:150%; line-height:200%;'>Visual Stellar Magnitude of the Sun at Any Given Distance</span><br><span style='font-size:90%;'>PHP Program by Jay Tanner</span>";

   $TableWidth = '777';

// -----------------------------------------
// Read input distance value from interface.

   $dist = trim(@$_POST['ArgDist']);

// ------------------------------
// Initialise distance to 1 unit.

   if ($dist == "") {$dist = 1;}

// --------------------------------------------
// Convert negative distance to absolute value.

   $dist = abs($dist);

// -------------------------------------
// Read distance units option selection.

   $RBB5 = array();
   $RBi5 = trim(@$_POST['RBB5']);

// -----------------------
// Number of radio buttons
// in each bank.

   $RBB5Count = 3;


// ----------------------------------------
// Set default input distance units to AUs.

   if ($RBi5 == '') {$RBi5 = 0;}

// -----------------------------------------
// Read output table mode states into array.

   for ($i=0;   $i < $RBB5Count;   $i++)
       {
        $RBB5[$i] = ($i == $RBi5)? 'CHECKED':'';
       }

// ----------------------------------
// Error if distance equates to zero.

   if ($dist == 0)

      {
       $out = "<div style='color:red; text-align:center; font-weight:bold;'>ERROR: The distance must be a numerical value greater than zero.</div>";
      }

else

{

// 149597870.691    = km per AU
// 9460730472580.8  = km per LY
// 30856775670468   = km per parsec

   $dist += 0;

// --------------------------------------
// Correct for proper English in numbers.

   $s = ($dist > 1)? "s" : "";

// ----------------------------
// Convert input units into AUs
// for internal computations.

    switch ($RBi5)
           {

//          -------------------
//          Handle case of AUs.

            case 0: $AU = $dist;
                    $u ="AU$s";
                    $dec = ".2f";
                    break;

//          ---------------------------
//          Handle case of light years.

            case 1: $AU = $dist * AU_PER_LY; // LY to AU
                    $u ="light year$s";
                    $dec = ".3f";
                    break;

//          -----------------------
//          Handle case of parsecs.

            case 2: $AU = $dist * AU_PER_PC; // pc to AU
                    $u = "parsec$s";
                    $dec = ".4f";
                    break;
           }


// --------------------------------------------
// Compute visual magnitude of Sun at given AU.

   $MagSun = 5*Log10($AU) - 26.74;

// ----------------------------------------------------
// Compute relative (from Earth = 1) brightness factor
// and brightness factor in percent (from Earth = 100).

   $BrFactor = pow(2.5118864315, -26.74 - $MagSun);

   $BrFactorPercent = 100 * $BrFactor;

// -------------------------------------------------------------
// Is the brightness less or brighter than as viewed from Earth?



   $ComparativeBrightness = ($BrFactorPercent < 100)? '':'';
   $ComparativeBrightness .= "(Earth = 100)";
   if($BrFactorPercent == 100) {$ComparativeBrightness = '';}


// -----------------------------------------
// Format magnitude value string for output.

   $MagSunOut = sprintf("%2" . $dec, $MagSun);
                if ($MagSun > 0)  {$MagSunOut = "+$MagSunOut";}

// --------------------------------------
// Determine number of decimals to apply.

   $MagDecimals = (abs($MagSun) < 10)? 3:2;


// --------------------------
// Format results for output.

// $MagSunOut = round($MagSunOut, $MagDecimals);
   $MagSunOut = sprintf("%+1.$MagDecimals".'f', $MagSunOut);

   $BrFactorPercent = sprintf ("%1.6f", $BrFactorPercent);


// ----------------------------
// Collect output computations.

   $out  = " Apparent brightness of the Sun at $dist $u:\n\n";
   $out .= " Visual Magnitude = $MagSunOut";


// --------------------------------------------
// Compute relative (from Earth = 1) brightness
// factor, but only if distance units = AUs.

   if ($RBi5 == 0)
      {
       $out .= "\n\n Relative Brightness Factor = $BrFactorPercent &#37; $ComparativeBrightness\n";
      }

}

// Generate HTML web page to display computed results.

print <<< _HTML

<!DOCTYPE HTML>

<html lang='en'>

<head>

<title>Stellar Magnitude of the Sun Calculator</title>

<meta http-equiv="content-type" content="text/html; charset=UTF-8">
<meta name="description" content="This PHP program calculates the stellar magnitude of the sun at any given distance.">
<meta name="keywords" content="Stellar magnitude of sun,magnitude of sun,solar magnitude">
<meta name="author" content="Jay Tanner - PHPScienceLabs.com">
<meta http-equiv='pragma'  content='no-cache'>
<meta http-equiv='expires' content='-1'>
<meta name='robots'    content='index,follow'>
<meta name='googlebot' content='index,follow'>
<link rel="canonical" href="https://www.phpsciencelabs.com/stellar-magnitude-of-sun-calculator">

<style>
 BODY
{color:silver; background-color:black; font-family:Verdana; font-size:100%;}

 TABLE
{font-size:12px; border: 1px solid black;}

PRE,CODE {font-size:125%; font-family:monospace;}

 TD
{color:black; background-color:white; line-height:200%; font-size:100%;
padding:6px; text-align:left;}

IMG {border:1px solid silver; box-shadow:2px 2px 3px #999999; border-radius:8px;}

 TEXTAREA
{
 color:black; background:white; font-family:monospace; font-size:150%;
 font-weight:bold; border-radius: 8px; border:1px solid black; padding:4px;
 white-space:pre;
}

 INPUT[type='text']::-ms-clear {width:0; height:0;}

 INPUT[type='text']
{
  font-family:monospace; color:black; background:white; font-size:150%;
 font-weight:bold; text-align:center; box-shadow:2px 2px 3px #666666;
 border:1px solid black; border-radius:0px;
}

 INPUT[type='text']:focus
{
 font-family:monospace; background:white; box-shadow:2px 2px 3px #666666;
 font-size:150%; border:2px solid blue; text-align:center; font-weight:bold;
}

 INPUT[type='submit']{font-weight:bold;}

 INPUT[type='submit']:hover
      {font-weight:bold; background:cyan; border-radius:4px;}

 HR {background:black; height:2px; border:0px;}

 A:link
{
 font-size:100%; background:transparent; color:blue; font-family:Verdana;
 font-weight:bold; text-decoration:none; line-height:175%; padding:3px;
 border:1px solid transparent;
}

 A:visited {font-size:100%; background:transparent; color:DarkCyan;}

 A:hover
{
 font-size:100%; background:yellow; color:black; border:1px solid black;
 box-shadow:1px 1px 3px #222222;
}

 A:active  {font-size:100%; background:yellow; color:black;}

::selection      {background-color:yellow !important;  color:black !important;}
::-moz-selection {background-color:yellow !important;  color:black !important;}
</style>

</head>

<body style='font-family:Verdana; font-size:110%;'>

<form name='form1' action="$_ACTION_FILE_NAME_" method='post'>

<table width="$TableWidth" cellpadding='4' cellspacing='2'>

<tr><td align='center' style='color:white; background:#000066; font-size:110%; text-align:center; border:2px solid white; border-radius:8px 8px 0px 0px;'>$_PAGE_HEADING_</td></tr>

<!-- Distance input -->
<tr>
<td align='center' style='color:black; font-size:100%;'>
<b>Distance from Sun &nbsp; </b><input name='ArgDist' type='text' size='16' value="$dist" maxlength='16'>&nbsp;&nbsp;
AUs&nbsp;<input name="RBB5" type="radio" value="0" $RBB5[0]>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
Light Years&nbsp;<input name="RBB5" type="radio" value="1" $RBB5[1]>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
Parsecs&nbsp;<input name="RBB5" type="radio" value="2" $RBB5[2]>
</td>
</tr>

<!-- Compute Button -->
<tr><td style='background-color:white; text-align:center;'><input name='Compute_Button' type='submit' value='Compute'></td></tr>

</table>

</form>

<br>

<!-- Output Display Table  -->

<table bgcolor='white' width="$TableWidth">
<tr><td>
<b><pre style='font-size:150%; color:black; background-color:LightYellow; border:1px solid black;'>$out</pre></b>
</td>
</tr>
</table>

<br>

<table width="$TableWidth" cellpadding='4' cellspacing='0'><tr><td>

<div style='font-size:120%; text-align:justify;'>
There are times when we may want to know how bright the sun would appear to be if viewed from a different perspective, such as how bright our sun might appear to be if viewed from Mercury or Pluto or even from another star many light years away.

<br><br>
This program applies the following magnitude versus distance formula to the problem of computing the apparent ideal visual stellar magnitude of the sun as viewed from any given distance expressed in astronomical units, light years or parsecs.

<br><br>
<b style='color:red;'>NOTE</b>:<br>
Space is being treated as 'crystal-clear' and free of any obscuring gas or dust, which is adequate for our purposes here.

<br><br>
<hr>
<b>Visual Magnitude vs. Distance</b>
<br><br>
The general magnitude vs. distance formula may be expressed as

<div><img src='images/m2_minus_m1.png' alt=''><br><span style='font-size:75%;'>Eq. 1</span></div>

Where:<sub>&nbsp;</sub><br>
<B>m<SUB>1</SUB></B> &nbsp;=&nbsp; Visual magnitude of a body as viewed from distance <b>d<sub>1</sub></b><sub>&nbsp;</sub>

<br>and<br>
<b>m<sub>2</sub></b> &nbsp;=&nbsp; Visual magnitude of the same body as viewed from distance <b>d<sub>2</sub></b>

<br><br>
In this case, the astronomical body is the Sun, but it could be a star, the moon, a planet, an asteroid, etc.&nbsp;
Given any three known values, using <i>Equation 1</i> above, we can directly derive the remaining unknown value.

<br><br>
When dealing with the basic problem of apparent stellar brightness and magnitude variation versus distance, there are three general units of distance we might apply, depending upon which is most convenient for the kind of work being done.&nbsp; These units are <i>astronomical units</i> (<b>AU)</b>, <i>light years</i> (<b>LY</b>) and <i>parsecs</i> (<b>pc</b>).

<br><br>
<pre style='background-color:LightYellow; font-size:125%; border:2px solid black; padding:8px; font-weight:bold; border-radius:8px;'>
WORKSHEET A

We first need to define some constants and derived working values.
The extra precision is for internal computational purposes. The
final computed result can be rounded to whatever precision is
practical.

-26.74 = Visual magnitude of the sun at 1.0 AU (NASA)

1 AU = 149597870700 m (NASA/IAU/2012)

Light Speed = 299792458 m/s (NIST)

1 Standard (Julian) Year = 365.25 days = 31557600 seconds

For light years and parsecs, we derive the following:

1 LY = (Light Speed) * (Seconds per Standard Year)
     = (299792458 m/s) * (31557600 s)
     = 9460730472580800 m

From which we derive the number of AUs per light year:
AU_PER_LY = (9460730472580800 m/LY) / (149597870700 m/AU)
          = 63241.0770842662802686 AU/LY

Since 1 parsec is the distance at which the sun has a parallax shift
of 1 second of arc, a parsec, expressed in AUs, equates to the number&nbsp;
of seconds of arc in a unit radian or 206264.806247 AUs per parsec.

ARCSEC_PER_RADIAN = ARCSEC_PER_DEG * 180 / pi
                  = 3600 * 180 / 3.1415926535897932
                  = 206264.8062470963551565 arcsec/rad

AU_PER_PC = ARCSEC_PER_RADIAN
          = 206264.8062470963551565 AU/pc

</pre>

<br>
Generally, we can say that for any distance units defined in terms of AUs:
<pre style='background-color:LightYellow; font-size:125%; border:2px solid black; padding:8px; font-weight:bold;  border-radius:8px;'>
WORKSHEET B

Generally:
m = 5 * log10(AU_PER_DISTANCE_UNIT) - 26.74


For visual magnitude of the sun at 1.0 AU:
m = 5 * log10(AU_PER_AU) - 26.74
  = 5 * log10(1) - 26.74
  = 5 * 0 - 26.74
  = -26.74

For visual magnitude of the sun at 1.0 LY:
m = 5 * log10(AU_PER_LY) - 26.74
  = 5 * log10(63241.077084) - 26.74
  = 5 * 4.800999  - 26.74
  = -2.735

For visual magnitude of the sun at 1.0 pc:
m = 5 * log10(AU_PER_PC) - 26.74
  = 5 * log10(206264.806247) - 26.74
  = 5 * 5.314425 - 26.74
  = -0.1679


So, we have now derived the constants for the three distance units
and can derive equations specific to each unit of measure:

-26.74  = Visual magnitude of sun at distance of 1.0 AU
-2.735  = Visual magnitude of sun at distance of 1.0 light year
-0.1679 = Visual magnitude of sun at distance of 1.0 parsec

</pre>

<br>
The following three visual magnitude versus distance equations were formulated specifically for application to the sun and were derived from <i>Equation 1</i> and the computational data given above.

<br><br>
For solar distance reckoned in astronomical units (AU):<br>
<p><img src='images/mag_vs_dist_aus.png' alt=''><br><span style='font-size:75%;'>Eq. 2</span></p>

<br><br>
For solar distance reckoned in light years (LY):<br>
<p><img src='images/mag_vs_dist_light_years.png' alt=''><br><span style='font-size:75%;'>Eq. 3</span></p>

<br><br>
For solar distance reckoned in parsecs (pc):<br>
<p><img src='images/mag_vs_dist_parsecs.png' alt=''><br><span style='font-size:75%;'>Eq. 4</span></p>

<br><br>
<div>
Ref:
<br><br>
<span style='font-size:90%; color:black;'>Solar visual magnitude at <code>1.0</code> AU (<code>-26.74</code>) came from the NASA solar factsheet:</span><br>
<a href='http://nssdc.gsfc.nasa.gov/planetary/factsheet/sunfact.html' target='_blank' title=' Tries to Open In a New Tab '>http://nssdc.gsfc.nasa.gov/planetary/factsheet/sunfact.html</a>
<br><br>
<span style='font-size:90%; color:black;'>Speed of light</code> (<code>299792458 m/s</code>) came from NIST:</span><br>
<a href='http://physics.nist.gov/cgi-bin/cuu/Value?c|search_for=light' target='_blank' title=' Tries to Open In a New Tab '>http://physics.nist.gov/cgi-bin/cuu/Value?c|search_for=light</a>
</div>

<br>
<div style='font-size:70%; text-align:center;'>Jay Tanner - $cYear - $ProgramVersion</div>

</td></tr></table>

</body>

</html>


_HTML;


?>


